@@ -16,8 +16,8 @@ use crate::{
     Error, Result,
 };
 use log::{debug, info};
-use safe_network::types::Keypair;
 use serde_json::json;
+use sn_interface::types::Keypair;
 use std::path::{Path, PathBuf};
 
 // Method for requesting application's authorisation
